package bin;

import kernel.peripherals.Peripherals.Peripheral;
import kernel.net.Routing;
import haxe.ds.ReadOnlyArray;
import lib.TermHandle;
import lib.CLIBase;

class Net extends CLIBase {
	private var handle:TermHandle;
	public function invoke(handle:TermHandle):Bool {
		this.handle = handle;

		var subcommand = handle.args[0];
		var subcommand_args = handle.args.slice(1);

		switch (subcommand) {
			case "route":
				return route(subcommand_args);
			case "iface":
				return iface(subcommand_args);
			case "help":
				printHelp();
				return true;
			case "ping":
				ping(subcommand_args);
			default:
				handle.writeLn("Unknown subcommand: " + subcommand);
				printHelp();
				return false;
		}

		return true;
	}

	private function printHelp() {
		handle.writeLn("net route");
		handle.writeLn("net iface");
		handle.writeLn("net help");
	}

	private function route(args:ReadOnlyArray<String>):Bool {
		var routes = Routing.instance.getRouteTable();

		for(k => v in routes) {
			handle.writeLn('${k} => ${v.interf.name()}(${v.cost})');
		}

		return true;
	}

	private function iface(args:ReadOnlyArray<String>):Bool {
		var modems = Peripheral.instance.getModems();

		for (modem in modems) {
			handle.writeLn(modem.name());
		}

		return true;
	}

	function ping(args:ReadOnlyArray<String>) {
		if (args.length != 1) {
			handle.writeLn("Usage: net ping id");
		}

		var toID:Null<Int> = Std.parseInt(args[0]);

		if (toID == null) {
			handle.writeLn("Invalid ID");
		}

		// var result = kernel.net.Net.instance.ping(toID);

	}
}
